<?php

namespace EventPortal\Http\Controllers\Admin;

use EventPortal\Domain\Form\Facades\Form;
use EventPortal\Domain\Permission\Models\Role;
use EventPortal\Domain\Util\AdminRender;
use EventPortal\Domain\Util\Breadcrumb;
use EventPortal\Http\Controllers\Controller;
use Illuminate\Http\RedirectResponse;
use Illuminate\Http\Request;
use Illuminate\Support\Str;
use Inertia\Response;

class RoleController extends Controller
{
    public function create(): Response
    {
        $form = Form::make('role.create')->model(new Role)->render();

        $breadcrumbs = Breadcrumb::make()
            ->add('Permissions', route('admin.permission.index'))
            ->add('Create a role')
            ->get();

        return AdminRender::component('Admin/Role/Create')
            ->key('role.create')
            ->withForm($form)
            ->withBreadcrumbs($breadcrumbs)
            ->get();
    }

    public function store(Request $request): RedirectResponse
    {
        Form::make('role.create')
            ->model(new Role)
            ->validate($request->all())
            ->handle([
                'name' => Str::kebab($request->name),
                'label' => $request->name,
            ]);

        toast()->success(trans('role.created'));

        return redirect()->route('admin.permission.index');
    }
}
